emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/ada-mode a4ecb2e2e2: * ada-mode.el: Bump version to 7.3


From: Stephen Leake
Subject: [elpa] externals/ada-mode a4ecb2e2e2: * ada-mode.el: Bump version to 7.3.beta1
Date: Mon, 11 Jul 2022 22:24:39 -0400 (EDT)

branch: externals/ada-mode
commit a4ecb2e2e2416cf6066d9a57d9823b257d0f389e
Author: Stephen Leake <stephen_leake@stephe-leake.org>
Commit: Stephen Leake <stephen_leake@stephe-leake.org>

    * ada-mode.el: Bump version to 7.3.beta1
    
    * ada_mode.prj: Add comment.
    
    * build.sh: Add verbosity, fix WISI_DIR algorithm for beta.
---
 ada-mode.el  |  2 +-
 ada_mode.prj |  1 +
 build.sh     | 20 +++++++++++++-------
 3 files changed, 15 insertions(+), 8 deletions(-)

diff --git a/ada-mode.el b/ada-mode.el
index 12eea01d71..8ec5544587 100644
--- a/ada-mode.el
+++ b/ada-mode.el
@@ -6,7 +6,7 @@
 ;; Maintainer: Stephen Leake <stephen_leake@stephe-leake.org>
 ;; Keywords: languages
 ;;  ada
-;; Version: 7.3.beta
+;; Version: 7.3.beta1
 ;; package-requires: ((uniquify-files "1.0.1") (wisi "4.0.beta") (emacs 
"25.3"))
 ;; url: http://www.nongnu.org/ada-mode/
 ;;
diff --git a/ada_mode.prj b/ada_mode.prj
index e02082d677..c45ed512e3 100644
--- a/ada_mode.prj
+++ b/ada_mode.prj
@@ -1,3 +1,4 @@
+--  For compiling in ELPA worktree
 gpr_project_path=$WISI
 
 gpr_file=ada_mode_wisi_parse.gpr
diff --git a/build.sh b/build.sh
index 6fad8f352b..ac6b778380 100755
--- a/build.sh
+++ b/build.sh
@@ -17,16 +17,21 @@ else
 fi
 
 # support for libadalang is still experimental
-gnatprep  -DHAVE_LIBADALANG="no" -DELPA="yes" -DHAVE_GNAT_UTIL=$HAVE_GNAT_UTIL 
ada_mode_wisi_parse.gpr.gp ada_mode_wisi_parse.gpr
+args=`echo -DHAVE_LIBADALANG="no" -DELPA="yes" 
-DHAVE_GNAT_UTIL=$HAVE_GNAT_UTIL ada_mode_wisi_parse.gpr.gp 
ada_mode_wisi_parse.gpr`
 
-if [ -d ../wisi-3.1.? ]; then
-    WISI_DIR=`ls -d ../wisi-3.1.?`
+echo "gnatprep " $args
+gnatprep $args
+
+if [ -d ../wisi-4.0.? ]; then
+    WISI_DIR=`ls -d ../wisi-4.0.?`
 else
     # try devel version
-    WISI_DIR=`ls -d ../wisi-3.1.?.0.*`
+    WISI_DIR=`find .. -type d -name "wisi-4.0beta*"`
 fi
 
-gnatprep -DELPA="yes" $WISI_DIR/wisi.gpr.gp $WISI_DIR/wisi.gpr
+args=`echo -DELPA="yes" $WISI_DIR/wisi.gpr.gp $WISI_DIR/wisi.gpr`
+echo "gnatprep " $args
+gnatprep $args
 
 # We don't add WISI_DIR to GPR_PROJECT_PATH because the user may have
 # already set GPR_PROJECT_PATH.
@@ -38,11 +43,12 @@ gprclean -r -P ada_mode_wisi_parse.gpr -aP$WISI_DIR
 
 gprbuild -p -j8 -P $WISI_DIR/wisi.gpr wisitoken-bnf-generate
 
 # We generate the Ada LR parse table .txt file here, because it is too
 # large to keep in ELPA. The code generated by wisitoken-bnf-generate
 # is in ELPA, because it requires the re2c tool, which we don't expect
 # users to have installed. The LR parse table for gpr is in the Ada
 # code, so we don't need to generate that here.
+echo "generate Ada LR1 parse table"
 $WISI_DIR/wisitoken-bnf-generate --task_count 1 ada_annex_p.wy
 
 gprbuild -p -j8 -P ada_mode_wisi_parse.gpr -aP $WISI_DIR "$@"
@@ -38,11 +43,12 @@ gprclean -r -P ada_mode_wisi_parse.gpr -aP$WISI_DIR
 gprbuild -p -j8 -P $WISI_DIR/wisi.gpr wisitoken-bnf-generate
 
-# We generate the Ada LR parse table .txt file here, because it is too
+# We generate the Ada LR1 parse table .txt file here, because it is too
 # large to keep in ELPA. The code generated by wisitoken-bnf-generate
 # is in ELPA, because it requires the re2c tool, which we don't expect
@@ -38,11 +43,12 @@ gprclean -r -P ada_mode_wisi_parse.gpr -aP$WISI_DIR
 # large to keep in ELPA. The code generated by wisitoken-bnf-generate
 # is in ELPA, because it requires the re2c tool, which we don't expect
-# users to have installed. The LR parse table for gpr is in the Ada
+# users to have installed. The LR1 parse table for gpr is in the Ada
 # code, so we don't need to generate that here.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]